==> is-typed-array-1.0.1.tgz: package/README.md <==
# @socketregistry/is-typed-array

[![Socket Badge](https://socket.dev/api/badge/npm/package/@socketregistry/is-typed-array)](https://socket.dev/npm/package/@socketregistry/is-typed-array)
[![CI - @socketregistry/is-typed-array](https://github.com/SocketDev/socket-registry-js/actions/workflows/test.yml/badge.svg)](https://github.com/SocketDev/socket-registry-js/actions/workflows/test.yml)
[![Follow @SocketSecurity](https://img.shields.io/twitter/follow/SocketSecurity?style=social)](https://twitter.com/SocketSecurity)

> A tested zero dependency drop-in replacement of
> [`is-typed-array`](https://www.npmjs.com/package/is-typed-array) complete with
> TypeScript types.

## Installation

### Install as a package override

[`@socketsecurity/cli`](https://www.npmjs.com/package/@socketsecurity/cli) will
automagically :sparkles: populate the
[overrides](https://docs.npmjs.com/cli/v9/configuring-npm/package-json#overrides)
and [resolutions](https://yarnpkg.com/configuration/manifest#resolutions) fields
of your `package.json`.

```sh
npx @socketsecurity/cli optimize
```

Prefer to do it yourself? You may manually add `@socketregistry/is-typed-array`
to your `package.json`.

```json
{
  "overrides": {
    "is-typed-array": "npm:@socketregistry/is-typed-array@^1"
  },
  "resolutions": {
    "is-typed-array": "npm:@socketregistry/is-typed-array@^1"
  }
}
```

### Install as a plain dependency

Install with your preferred package manager.

```sh
npm install @socketregistry/is-typed-array
```

## Requirements

Node >= `18.20.4`

==> is-typed-array-1.0.2.tgz: package/README.md <==
# @socketregistry/is-typed-array

[![Socket Badge](https://socket.dev/api/badge/npm/package/@socketregistry/is-typed-array)](https://socket.dev/npm/package/@socketregistry/is-typed-array)
[![CI - @socketregistry/is-typed-array](https://github.com/SocketDev/socket-registry-js/actions/workflows/test.yml/badge.svg)](https://github.com/SocketDev/socket-registry-js/actions/workflows/test.yml)
[![Follow @SocketSecurity](https://img.shields.io/twitter/follow/SocketSecurity?style=social)](https://twitter.com/SocketSecurity)

> A tested zero dependency drop-in replacement of
> [`is-typed-array`](https://socket.dev/npm/package/is-typed-array) complete
> with TypeScript types.

## Installation

### Install as a package override

[`@socketsecurity/cli`](https://socket.dev/npm/package/@socketsecurity/cli) will
automagically :sparkles: populate the
[overrides](https://docs.npmjs.com/cli/v9/configuring-npm/package-json#overrides)
and [resolutions](https://yarnpkg.com/configuration/manifest#resolutions) fields
of your `package.json`.

```sh
npx @socketsecurity/cli optimize
```

Prefer to do it yourself? You may manually add `@socketregistry/is-typed-array`
to your `package.json`.

```json
{
  "overrides": {
    "is-typed-array": "npm:@socketregistry/is-typed-array@^1"
  },
  "resolutions": {
    "is-typed-array": "npm:@socketregistry/is-typed-array@^1"
  }
}
```

### Install as a plain dependency

Install with your preferred package manager.

```sh
npm install @socketregistry/is-typed-array
```

## Requirements

Node >= `18.20.4`
